Ep16 La Dent d'Or - Assurons-nous bien du fait avant de nous inquiéter de la cause

Hygiène Mentale

Ep16 La Dent d'Or - Assurons-nous bien du fait avant de nous inquiéter de la cause

Il y a des histoires qui ne vieillissent pas.
L'histoire de la dent d'or est de celles là.
Fontenelle a raconté cette histoire il y a 350 ans. C'était déjà une vieille histoire a son époque, et il précise pourquoi il est toujours important de la raconter.
Jean Rostand (un autre penseur sceptique) a rappelé il y a 60 ans pourquoi il est toujours important de la raconter.
Du coup je les ai pris aux mot, et je vous raconte cette histoire, en vidéo d'animation. Par ce que aujourd'hui encore il est toujours important de la raconter.
__________________
La vidéo de Scilabus sur le protocole expérimental :
https://www.youtube.com/watch?v=P2oSxXyNSiw&t=321s
L'histoire de la Dent d'Or de Fontenelle
https://fr.wikipedia.org/wiki/Histoire_des_oracles#L.E2.80.99histoire_de_la_dent_d.E2.80.99or
Sciences Fausses et Fausses sciences (et viceversa 😉)
http://www.persee.fr/doc/rhs_0048-7996_1961_num_14_3_3961
_
Musique d'intro : Koenjiyakkei- Angherr Shisspa
Le facebook : http://facebook.com/HygieneMentale
Le twitter : https://twitter.com/HygieneMentale
Le Diaspora* : https://framasphere.org/people/43360ee086750134e9c62a0000053625
Le site : http://laelith.fr/Zet
L'association : http://zetetique.fr
Le Tipee : https://www.tipeee.com/hygiene-mentale

04/03/2017